<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit87fd6d6d9b9c6bd76ae61b0c1fa51f68
{
    public static $prefixLengthsPsr4 = array (
        'A' => 
        array (
            'AIOSEO\\Plugin\\Addon\\ImageSeo\\' => 29,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'AIOSEO\\Plugin\\Addon\\ImageSeo\\' => 
        array (
            0 => __DIR__ . '/../..' . '/app',
        ),
    );

    public static $classMap = array (
        'AIOSEO\\Plugin\\Addon\\ImageSeo\\Admin\\Admin' => __DIR__ . '/../..' . '/app/Admin/Admin.php',
        'AIOSEO\\Plugin\\Addon\\ImageSeo\\ImageSeo' => __DIR__ . '/../..' . '/app/ImageSeo.php',
        'AIOSEO\\Plugin\\Addon\\ImageSeo\\Image\\Image' => __DIR__ . '/../..' . '/app/Image/Image.php',
        'AIOSEO\\Plugin\\Addon\\ImageSeo\\Utils\\Helpers' => __DIR__ . '/../..' . '/app/Utils/Helpers.php',
        'AIOSEO\\Plugin\\Addon\\ImageSeo\\Utils\\Tags' => __DIR__ . '/../..' . '/app/Utils/Tags.php',
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit87fd6d6d9b9c6bd76ae61b0c1fa51f68::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit87fd6d6d9b9c6bd76ae61b0c1fa51f68::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit87fd6d6d9b9c6bd76ae61b0c1fa51f68::$classMap;

        }, null, ClassLoader::class);
    }
}
