<?php

// autoload_files.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    '81db02b30f563b92907e271b66bd7559' => $vendorDir . '/yoast/whip/src/Facades/wordpress.php',
);
