<?php return array(
    'root' => array(
        'name' => 'awesomemotive/aioseo-image-seo',
        'pretty_version' => 'dev-develop',
        'version' => 'dev-develop',
        'reference' => 'b5b59ac2e48110aa305687e8d1d9972852f01a06',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'awesomemotive/aioseo-image-seo' => array(
            'pretty_version' => 'dev-develop',
            'version' => 'dev-develop',
            'reference' => 'b5b59ac2e48110aa305687e8d1d9972852f01a06',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
